@@ -28,18 +28,12 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // ---
-// Author: Ryoji Watanabe
 
-#include "config.h"
+#include <config.h>
 #include <ctemplate/template_annotator.h>
-
 #include <string>
 #include <ctemplate/template_emitter.h>
 
-using std::string;
-
-_START_GOOGLE_NAMESPACE_
-
 // Emits an open annotation string.  'name' must be a string literal.
 #define EMIT_OPEN_ANNOTATION(emitter, name, value)      \
   (emitter)->Emit("{{#" name "=", 4 + sizeof(name)-1);  \
@@ -55,6 +49,10 @@ _START_GOOGLE_NAMESPACE_
   (emitter)->Emit(value);                               \
   (emitter)->Emit("}}", 2);
 
+_START_GOOGLE_NAMESPACE_
+
+using std::string;
+
 // Implementation note: TextTemplateAnnotator contains no state, and
 // code elsewhere is depending on this.  E.g., a statically allocated
 // instance is used as the default annotator in the implementation of
